import React, { useState } from "react";
import InputWithDropDown from "../../../ui/inputs/InputWithDropDown";
import { ArrowIcon } from "../../../icons/ExportCommonIcons";

// image imports
import Arc from "../../../../assets/image/aisleTypes/Arc.png";
import Arrow from "../../../../assets/image/aisleTypes/Arrow.png";
import Arrows from "../../../../assets/image/aisleTypes/Arrows.png";
import Circle from "../../../../assets/image/aisleTypes/Circle.png";
import Dashed from "../../../../assets/image/aisleTypes/Dashed.png";
import Directional from "../../../../assets/image/aisleTypes/Directional.png";
import Dotted from "../../../../assets/image/aisleTypes/Dotted.png";
import Solid from "../../../../assets/image/aisleTypes/Solid.png";

interface TextureItem {
  color: string;
  id: string;
  brief: string;
  texture: string;
}

const AisleProperties: React.FC = () => {
  const [collapsePresets, setCollapsePresets] = useState(false);
  const [collapseTexture, setCollapseTexture] = useState(true);
  const [selectedTexture, setSelectedTexture] = useState<string | null>(
    "yellow1"
  );
  const [selectedType, setSelectedType] = useState<string | null>("Solid");

  const aisleTextureList: TextureItem[] = [
    { color: "gray", id: "gray", brief: "basic", texture: "" },
    {
      color: "yellow",
      id: "yellow1",
      brief: "pedestrian walkways",
      texture: "",
    },
    { color: "green", id: "green1", brief: "pedestrian walkways", texture: "" },
    { color: "orange", id: "orange", brief: "material flow", texture: "" },
    { color: "blue", id: "blue", brief: "vehicle paths", texture: "" },
    { color: "purple", id: "purple", brief: "material flow", texture: "" },
    { color: "red", id: "red", brief: "safety zone", texture: "" },
    {
      color: "bright green",
      id: "bright-green",
      brief: "safety zone",
      texture: "",
    },
    {
      color: "yellow-black",
      id: "yellow-black",
      brief: "utility aisles",
      texture: "",
    },
    {
      color: "white-black",
      id: "white-black",
      brief: "utility aisles",
      texture: "",
    },
  ];

  const aisleTypes = [
    {
      name: "Solid",
      id: "1",
      thumbnail: Solid,
    },
    {
      name: "Dotted",
      id: "2",
      thumbnail: Dotted,
    },
    {
      name: "Dashed",
      id: "3",
      thumbnail: Dashed,
    },
    {
      name: "Arrow",
      id: "4",
      thumbnail: Arrow,
    },
    {
      name: "Contiuous Arrows",
      id: "5",
      thumbnail: Arrows,
    },
    {
      name: "Directional",
      id: "6",
      thumbnail: Directional,
    },
    {
      name: "Arc",
      id: "7",
      thumbnail: Arc,
    },
    {
      name: "Circle",
      id: "8",
      thumbnail: Circle,
    },
  ];

  return (
    <div className="aisle-properties-container">
      <div className="header">Properties</div>
      <section>
        <InputWithDropDown
          label="Width"
          value="1"
          editableLabel
          onChange={() => {}}
        />
      </section>

      {/* Presets */}
      <section>
        <button
          className="header"
          onClick={() => setCollapsePresets(!collapsePresets)}
          aria-expanded={!collapsePresets}
        >
          <div className="value">Presets</div>
          <div className="icon">
            <ArrowIcon />
          </div>
        </button>
        {!collapsePresets && (
          <div className="presets-list-container">
            {aisleTypes.map((val) => (
              <div className="preset-list" key={val.id}>
                <button
                  className={`thumbnail ${
                    selectedType === val.name ? "selected" : ""
                  }`}
                  title={val.name}
                  onClick={() => {
                    setSelectedType(val.name);
                  }}
                >
                  <img src={val.thumbnail} alt="" />
                </button>
              </div>
            ))}
          </div>
        )}
      </section>

      {/* Texture */}
      <section>
        <button
          className="header"
          onClick={() => setCollapseTexture(!collapseTexture)}
          aria-expanded={!collapseTexture}
        >
          <div className="value">Aisle Texture</div>
          <div
            className="icon"
            style={{ rotate: collapseTexture ? "" : "-90deg" }}
          >
            <ArrowIcon />
          </div>
        </button>

        {collapseTexture && (
          <div className="aisle-texture-container">
            {aisleTextureList.map((val) => (
              <button
                key={val.id}
                title={val.brief || val.id}
                className={`aisle-list ${
                  selectedTexture === val.id ? "selected" : ""
                }`}
                onClick={() => setSelectedTexture(val.id)}
                aria-pressed={selectedTexture === val.id}
              >
                <div className="texture-display">{val.texture}</div>
                <div className="aisle-color">{val.color}</div>
                <div className="aisle-brief">{`( ${val.brief} )`}</div>
              </button>
            ))}
          </div>
        )}
      </section>
    </div>
  );
};

export default AisleProperties;
